@@ -16,10 +16,10 @@ use English qw/ -no_match_vars /;
 use Template;
 use Template::Provider;
 use YAML qw/Load/;
-use Path::Class qw/file/;
+use Path::Tiny;
 use base qw/App::TemplateCMD::Command/;
 
-our $VERSION     = version->new('0.6.2');
+our $VERSION     = version->new('0.6.4');
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 
@@ -36,7 +36,7 @@ sub process {
 
     for my $file (keys %{ $structure }) {
         my $template = $structure->{$file}{template};
-        my $file = file $file;
+        my $file = path($file);
 
         if ( !-e $file || $option{force} ) {
             $file->parent->mkpath();
@@ -88,7 +88,7 @@ App::TemplateCMD::Command::Build - Builds a a tree of files from a build templat
 
 =head1 VERSION
 
-This documentation refers to App::TemplateCMD::Command::Build version 0.6.2.
+This documentation refers to App::TemplateCMD::Command::Build version 0.6.4.
 
 =head1 SYNOPSIS
 
